==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/Version.java <==
package io.github.cdklabs.projen;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.455Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Version")
public class Version extends io.github.cdklabs.projen.Component {

    protected Version(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Version(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        STANDARD_VERSION = software.amazon.jsii.JsiiObject.jsiiStaticGet(io.github.cdklabs.projen.Version.class, "STANDARD_VERSION", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Version(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.VersionOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static java.lang.String STANDARD_VERSION;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getBumpTask() {
        return software.amazon.jsii.Kernel.get(this, "bumpTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) The name of the changelog file (under `artifactsDirectory`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getChangelogFileName() {
        return software.amazon.jsii.Kernel.get(this, "changelogFileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The name of the file that contains the release tag (under `artifactsDirectory`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getReleaseTagFileName() {
        return software.amazon.jsii.Kernel.get(this, "releaseTagFileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getUnbumpTask() {
        return software.amazon.jsii.Kernel.get(this, "unbumpTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) The name of the file that contains the version (under `artifactsDirectory`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getVersionFileName() {
        return software.amazon.jsii.Kernel.get(this, "versionFileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.Version}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.Version> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.VersionOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.VersionOptions.Builder();
        }

        /**
         * (experimental) The name of the directory into which `changelog.md` and `version.txt` files are emitted.
         * <p>
         * @return {@code this}
         * @param artifactsDirectory The name of the directory into which `changelog.md` and `version.txt` files are emitted. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder artifactsDirectory(final java.lang.String artifactsDirectory) {
            this.options.artifactsDirectory(artifactsDirectory);
            return this;
        }

        /**
         * (experimental) A name of a .json file to set the `version` field in after a bump.
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * // Example automatically generated from non-compiling source. May contain errors.
         * "package.json"
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param versionInputFile A name of a .json file to set the `version` field in after a bump. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder versionInputFile(final java.lang.String versionInputFile) {
            this.options.versionInputFile(versionInputFile);
            return this;
        }

        /**
         * (experimental) Custom configuration for versionrc file used by standard-release.
         * <p>
         * @return {@code this}
         * @param versionrcOptions Custom configuration for versionrc file used by standard-release. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder versionrcOptions(final java.util.Map<java.lang.String, ? extends java.lang.Object> versionrcOptions) {
            this.options.versionrcOptions(versionrcOptions);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.Version}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.Version build() {
            return new io.github.cdklabs.projen.Version(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/Version.java <==
package io.github.cdklabs.projen;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.163Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Version")
public class Version extends io.github.cdklabs.projen.Component {

    protected Version(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Version(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        STANDARD_VERSION = software.amazon.jsii.JsiiObject.jsiiStaticGet(io.github.cdklabs.projen.Version.class, "STANDARD_VERSION", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Version(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.VersionOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static java.lang.String STANDARD_VERSION;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getBumpTask() {
        return software.amazon.jsii.Kernel.get(this, "bumpTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) The name of the changelog file (under <code>artifactsDirectory</code>).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getChangelogFileName() {
        return software.amazon.jsii.Kernel.get(this, "changelogFileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The name of the file that contains the release tag (under <code>artifactsDirectory</code>).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getReleaseTagFileName() {
        return software.amazon.jsii.Kernel.get(this, "releaseTagFileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getUnbumpTask() {
        return software.amazon.jsii.Kernel.get(this, "unbumpTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) The name of the file that contains the version (under <code>artifactsDirectory</code>).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getVersionFileName() {
        return software.amazon.jsii.Kernel.get(this, "versionFileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.Version}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.Version> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.VersionOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.VersionOptions.Builder();
        }

        /**
         * (experimental) The name of the directory into which <code>changelog.md</code> and <code>version.txt</code> files are emitted.
         * <p>
         * @return {@code this}
         * @param artifactsDirectory The name of the directory into which <code>changelog.md</code> and <code>version.txt</code> files are emitted. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder artifactsDirectory(final java.lang.String artifactsDirectory) {
            this.options.artifactsDirectory(artifactsDirectory);
            return this;
        }

        /**
         * (experimental) A name of a .json file to set the <code>version</code> field in after a bump.
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * "package.json"
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param versionInputFile A name of a .json file to set the <code>version</code> field in after a bump. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder versionInputFile(final java.lang.String versionInputFile) {
            this.options.versionInputFile(versionInputFile);
            return this;
        }

        /**
         * (experimental) Find commits that should be considered releasable Used to decide if a release is required.
         * <p>
         * Default: ReleasableCommits.everyCommit()
         * <p>
         * @return {@code this}
         * @param releasableCommits Find commits that should be considered releasable Used to decide if a release is required. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder releasableCommits(final io.github.cdklabs.projen.ReleasableCommits releasableCommits) {
            this.options.releasableCommits(releasableCommits);
            return this;
        }

        /**
         * (experimental) The tag prefix corresponding to this version.
         * <p>
         * @return {@code this}
         * @param tagPrefix The tag prefix corresponding to this version. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tagPrefix(final java.lang.String tagPrefix) {
            this.options.tagPrefix(tagPrefix);
            return this;
        }

        /**
         * (experimental) Custom configuration for versionrc file used by standard-release.
         * <p>
         * @return {@code this}
         * @param versionrcOptions Custom configuration for versionrc file used by standard-release. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder versionrcOptions(final java.util.Map<java.lang.String, ? extends java.lang.Object> versionrcOptions) {
            this.options.versionrcOptions(versionrcOptions);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.Version}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.Version build() {
            return new io.github.cdklabs.projen.Version(
                this.project,
                this.options.build()
            );
        }
    }
}
